@@ -19,6 +19,7 @@ from lkml.keys import (
 )
 from lkml.tree import (
     BlockNode,
+    Comma,
     ContainerNode,
     DocumentNode,
     ExpressionSyntaxToken,
@@ -210,14 +211,21 @@ class DictParser:
         parent key. If its parent key is `access_grant`, it is a list and cannot be
         repeated. Otherwise, it can be repeated.
 
+        The parent key `query` is also a special case, where children are kept as lists.
+        See issue #53.
+
         Args:
             key: The name of the key to test.
 
         """
         singular_key = singularize(key)
-        return singular_key in PLURAL_KEYS and not (
-            singular_key == "allowed_value"
-            and self.parent_key.rstrip("s") == "access_grant"
+        return (
+            singular_key in PLURAL_KEYS
+            and not (
+                singular_key == "allowed_value"
+                and self.parent_key.rstrip("s") == "access_grant"
+            )
+            and not (self.parent_key == "query")
         )
 
     def resolve_filters(self, values: List[dict]) -> Union[List[BlockNode], ListNode]:
@@ -389,7 +397,7 @@ class DictParser:
 
         # Choose newline delimiting or space delimiting based on contents
         if len(values) >= 5 or pair_mode:
-            trailing_comma = True
+            trailing_comma: Optional[Comma] = Comma()
             self.increase_level()
             for value in values:
                 if pair_mode:
@@ -407,7 +415,7 @@ class DictParser:
             self.decrease_level()
             right_bracket = RightBracket(prefix=self.newline_indent)
         else:
-            trailing_comma = False
+            trailing_comma = None
             for i, value in enumerate(values):
                 value = cast(str, value)
                 if i == 0:
